@@ -1056,7 +1056,8 @@ class ConfigProvider:
         self.PIPELINE_SAMPLING_ENDPOINT = data["Azure"]["Azureml"]["Pipelines"]["Sampling"]["EndPoint"]
         #Model
         self.MODEL_NAME = data["Azure"]["Azureml"]["Model"]["Name"]
-        self.SURROGATE_MODEL = data["Azure"]["Azureml"]["SurrogateModel"]["Name"]
+        self.SURROGATE_MODEL_NAME = data["Azure"]["Azureml"]["SurrogateModel"]["Name"]
+        self.SURROGATE_VECTORIZER = data["Azure"]["Azureml"]["SurrogateModel"]["Vectorizer"]
         #Deploy
         self.DEPLOY_SERVICE_NAME = data["Azure"]["Azureml"]["Deploy"]["ServiceName"]
         self.DEPLOY_THRESHOLD =  data["Azure"]["Azureml"]["Deploy"]["ModelThreshold"]
